from django.db.models.loading import get_model
from django.utils.translation import ugettext as _
from django.core.urlresolvers import reverse
from django.conf import settings
from django.contrib import admin

from admin_tools.menu import items, Menu
from jumbo.conf.admin_menu import GenericMenuItem
from jumbo.middleware.thread_local import get_current_user


def get_root_menu(children):
    user = get_current_user()

    if user.has_perm("organization.view_organization") and get_model("organization", "organization") in admin.site._registry:
        root_menu = items.MenuItem(
            title=_('Organizations'),
            children=[],
            url = reverse('admin:organization_organization_changelist')
        )
        children.append(root_menu)
    return None

def add_extended_menuitems(children, current_app):
    generic_menu = GenericMenuItem(current_app, ['organization', 'contact'])
    user = get_current_user()

    if "asterisk" in settings.INSTALLED_APPS:
        save_in_addressbook = items.MenuItem(
            title=_('Save in addressbook'),
            children=[],
            url = reverse('admin:organization_organization_save_in_addressbook')
        )
        if user.has_perm('organization.save_addressbook'):
            generic_menu.add_child(save_in_addressbook, 'organization')

    organization_menu = generic_menu.get_menu()
    [ children.append(org_menu) for org_menu in organization_menu ]
